@@ -55,7 +55,7 @@ struct _h_connection * h_connect_mariadb(const char * host, const char * user, c
   bool reconnect = 1;
   o_malloc_t malloc_fn;
   o_free_t free_fn;
-  
+
   o_get_alloc_funcs(&malloc_fn, NULL, &free_fn);
   json_set_alloc_funcs((json_malloc_t)malloc_fn, (json_free_t)free_fn);
 
@@ -65,7 +65,7 @@ struct _h_connection * h_connect_mariadb(const char * host, const char * user, c
       y_log_message(Y_LOG_LEVEL_ERROR, "Hoel - Error allocating memory for conn");
       return NULL;
     }
-    
+
     conn->type = HOEL_DB_TYPE_MARIADB;
     conn->connection = o_malloc(sizeof(struct _h_mariadb));
     if (conn->connection == NULL) {
@@ -121,13 +121,16 @@ void h_close_mariadb(struct _h_connection * conn) {
  * returned value must be free'd after use
  */
 char * h_escape_string_mariadb(const struct _h_connection * conn, const char * unsafe) {
-  char * escaped = o_malloc(2 * strlen(unsafe) + sizeof(char));
+  char * escaped = o_malloc(2 * o_strlen(unsafe) + 1), * to_return = NULL;
   if (escaped == NULL) {
     y_log_message(Y_LOG_LEVEL_ERROR, "Hoel - Error allocating memory for escaped");
     return NULL;
   }
-  mysql_real_escape_string(((struct _h_mariadb *)conn->connection)->db_handle, escaped, unsafe, strlen(unsafe));
-  return escaped;
+  escaped[0] = '\0';
+  mysql_real_escape_string(((struct _h_mariadb *)conn->connection)->db_handle, escaped, unsafe, o_strlen(unsafe));
+  to_return = o_strdup(escaped);
+  o_free(escaped);
+  return to_return;
 }
 
 /**
@@ -137,7 +140,7 @@ char * h_escape_string_mariadb(const struct _h_connection * conn, const char * u
 char * h_escape_string_with_quotes_mariadb(const struct _h_connection * conn, const char * unsafe) {
   char * escaped = h_escape_string_mariadb(conn, unsafe), * escaped_returned = NULL;
   if (escaped == NULL) {
-    y_log_message(Y_LOG_LEVEL_ERROR, "Hoel - Error allocating memory for escaped");
+    y_log_message(Y_LOG_LEVEL_ERROR, "Hoel - Error h_escape_string_mariadb");
     return NULL;
   }
   escaped_returned = msprintf("'%s'", escaped);
@@ -172,7 +175,7 @@ int h_execute_query_mariadb(const struct _h_connection * conn, const char * quer
   struct _h_data * data, * cur_row = NULL;
   unsigned long * lengths;
   int res;
-  
+
   if (pthread_mutex_lock(&(((struct _h_mariadb *)conn->connection)->lock))) {
     return H_ERROR_QUERY;
   }
@@ -183,20 +186,20 @@ int h_execute_query_mariadb(const struct _h_connection * conn, const char * quer
     pthread_mutex_unlock(&(((struct _h_mariadb *)conn->connection)->lock));
     return H_ERROR_QUERY;
   }
-  
+
   if (h_result != NULL) {
     result = mysql_store_result(((struct _h_mariadb *)conn->connection)->db_handle);
-    
+
     if (result == NULL) {
       y_log_message(Y_LOG_LEVEL_ERROR, "Error executing mysql_store_result");
       y_log_message(Y_LOG_LEVEL_DEBUG, "Error message: \"%s\"", mysql_error(((struct _h_mariadb *)conn->connection)->db_handle));
       pthread_mutex_unlock(&(((struct _h_mariadb *)conn->connection)->lock));
       return H_ERROR_QUERY;
     }
-    
+
     num_fields = mysql_num_fields(result);
     fields = mysql_fetch_fields(result);
-    
+
     h_result->nb_rows = 0;
     h_result->nb_columns = num_fields;
     h_result->data = NULL;
@@ -222,7 +225,7 @@ int h_execute_query_mariadb(const struct _h_connection * conn, const char * quer
     }
     mysql_free_result(result);
   }
-  
+
   pthread_mutex_unlock(&(((struct _h_mariadb *)conn->connection)->lock));
   return H_OK;
 }
@@ -242,7 +245,7 @@ int h_execute_query_json_mariadb(const struct _h_connection * conn, const char *
   json_t * j_data;
   struct _h_data * h_data;
   char date_stamp[20];
-  
+
   if (pthread_mutex_lock(&(((struct _h_mariadb *)conn->connection)->lock))) {
     return H_ERROR_QUERY;
   }
@@ -251,7 +254,7 @@ int h_execute_query_json_mariadb(const struct _h_connection * conn, const char *
     pthread_mutex_unlock(&(((struct _h_mariadb *)conn->connection)->lock));
     return H_ERROR_PARAMS;
   }
-  
+
   *j_result = json_array();
   if (*j_result == NULL) {
     y_log_message(Y_LOG_LEVEL_ERROR, "Hoel - Error allocating memory for *j_result");
@@ -267,9 +270,9 @@ int h_execute_query_json_mariadb(const struct _h_connection * conn, const char *
     json_decref(*j_result);
     return H_ERROR_QUERY;
   }
-  
+
   result = mysql_store_result(((struct _h_mariadb *)conn->connection)->db_handle);
-  
+
   if (result == NULL) {
     y_log_message(Y_LOG_LEVEL_ERROR, "Error executing mysql_store_result");
     y_log_message(Y_LOG_LEVEL_DEBUG, "Error message: \"%s\"", mysql_error(((struct _h_mariadb *)conn->connection)->db_handle));
@@ -277,10 +280,10 @@ int h_execute_query_json_mariadb(const struct _h_connection * conn, const char *
     json_decref(*j_result);
     return H_ERROR_QUERY;
   }
-  
+
   num_fields = mysql_num_fields(result);
   fields = mysql_fetch_fields(result);
-  
+
   for (row = 0; (m_row = mysql_fetch_row(result)) != NULL; row++) {
     j_data = json_object();
     if (j_data == NULL) {
@@ -321,7 +324,7 @@ int h_execute_query_json_mariadb(const struct _h_connection * conn, const char *
   }
   mysql_free_result(result);
   pthread_mutex_unlock(&(((struct _h_mariadb *)conn->connection)->lock));
-  
+
   return H_OK;
 }
 
@@ -336,7 +339,7 @@ struct _h_data * h_get_mariadb_value(const char * value, const unsigned long len
   double d_value;
   struct tm tm_value;
   char * endptr;
-  
+
   if (value != NULL) {
     switch (m_type) {
       case FIELD_TYPE_DECIMAL:
@@ -441,4 +444,48 @@ void h_close_mariadb(struct _h_connection * conn) {
   y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with MariaDB backend");
 }
 
+char * h_escape_string_mariadb(const struct _h_connection * conn, const char * unsafe) {
+  UNUSED(conn);
+  UNUSED(unsafe);
+  y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with MariaDB backend");
+  return NULL;
+}
+
+char * h_escape_string_with_quotes_mariadb(const struct _h_connection * conn, const char * unsafe) {
+  UNUSED(conn);
+  UNUSED(unsafe);
+  y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with MariaDB backend");
+  return NULL;
+}
+
+long long int h_last_insert_id_mariadb(const struct _h_connection * conn) {
+  UNUSED(conn);
+  y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with MariaDB backend");
+  return 0;
+}
+
+int h_execute_query_mariadb(const struct _h_connection * conn, const char * query, struct _h_result * h_result) {
+  UNUSED(conn);
+  UNUSED(query);
+  UNUSED(h_result);
+  y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with MariaDB backend");
+  return H_ERROR;
+}
+
+int h_execute_query_json_mariadb(const struct _h_connection * conn, const char * query, json_t ** j_result) {
+  UNUSED(conn);
+  UNUSED(query);
+  UNUSED(j_result);
+  y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with MariaDB backend");
+  return H_ERROR;
+}
+
+struct _h_data * h_get_mariadb_value(const char * value, const unsigned long length, const int m_type) {
+  UNUSED(value);
+  UNUSED(length);
+  UNUSED(m_type);
+  y_log_message(Y_LOG_LEVEL_ERROR, "Hoel was not compiled with MariaDB backend");
+  return NULL;
+}
+
 #endif
